@@ -1009,10 +1009,16 @@ namespace GPBoost {
 		const double& tr_BI_B_deriv,
 		double& c_opt) {
 
-		vec_t centered_zt_AI_A_deriv_PI_z = zt_AI_A_deriv_PI_z.array() - tr_AI_A_deriv;
 		vec_t centered_zt_BI_B_deriv_PI_z = zt_BI_B_deriv_PI_z.array() - tr_BI_B_deriv;
-		c_opt = (centered_zt_AI_A_deriv_PI_z.cwiseProduct(centered_zt_BI_B_deriv_PI_z)).mean();
-		c_opt /= (centered_zt_BI_B_deriv_PI_z.cwiseProduct(centered_zt_BI_B_deriv_PI_z)).mean();
+		double c_denom = (centered_zt_BI_B_deriv_PI_z.cwiseProduct(centered_zt_BI_B_deriv_PI_z)).mean();
+		if (c_denom == 0) {
+			c_opt = 1;
+		}
+		else {
+			vec_t centered_zt_AI_A_deriv_PI_z = zt_AI_A_deriv_PI_z.array() - tr_AI_A_deriv;
+			c_opt = (centered_zt_AI_A_deriv_PI_z.cwiseProduct(centered_zt_BI_B_deriv_PI_z)).mean();
+			c_opt /= c_denom;
+		}
 	} // end CalcOptimalC
 
 	void CalcOptimalCVectorized(const den_mat_t& Z_AI_A_deriv_PI_Z,
