@@ -710,7 +710,6 @@ GPBOOST_C_EXPORT SEXP GPB_REModelFree_R(
 * \param optimizer Options: "gradient_descent" or "fisher_scoring"
 * \param momentum_offset Number of iterations for which no mometum is applied in the beginning
 * \param convergence_criterion The convergence criterion used for terminating the optimization algorithm. Options: "relative_change_in_log_likelihood" (default) or "relative_change_in_parameters"
-* \param calc_std_dev If true, approximate standard deviations are calculated (= square root of diagonal of the inverse Fisher information for Gaussian likelihoods and square root of diagonal of a numerically approximated inverse Hessian for non-Gaussian likelihoods)
 * \param num_covariates Number of covariates
 * \param init_coef Initial values for the regression coefficients
 * \param lr_coef Learning rate for fixed-effect linear coefficients
@@ -744,7 +743,6 @@ GPBOOST_C_EXPORT SEXP GPB_SetOptimConfig_R(
 	SEXP optimizer,
 	SEXP momentum_offset,
 	SEXP convergence_criterion,
-	SEXP calc_std_dev,
 	SEXP num_covariates,
 	SEXP init_coef,
 	SEXP lr_coef,
@@ -824,6 +822,11 @@ GPBOOST_C_EXPORT SEXP GPB_GetCurrentNegLogLikelihood_R(
 	SEXP negll
 );
 
+GPBOOST_C_EXPORT SEXP GPB_CanCalculateStandardErrorsCovPars_R(
+	SEXP handle,
+	SEXP out
+);
+
 /*!
 * \brief Get covariance parameters
 *		 Note: You should pre-allocate memory for optim_cov_pars. Its length equals the number of covariance parameters (num_cov_pars) or twice this if calc_std_dev = true
@@ -1037,6 +1040,28 @@ GPBOOST_C_EXPORT SEXP GPB_GetCovariateData_R(
 	SEXP covariate_data
 );
 
+/*!
+* \brief Return offset data
+* \param handle Handle of REModel
+* \param[out] fixed_effects offset data
+* \return 0 when succeed, -1 when failure happens
+*/
+GPBOOST_C_EXPORT SEXP GPB_GetOffsetData_R(
+	SEXP handle,
+	SEXP fixed_effects
+);
+
+/*!
+* \brief Set offset data
+* \param handle Handle of REModel
+* \param fixed_effects offset data
+* \return 0 when succeed, -1 when failure happens
+*/
+GPBOOST_C_EXPORT SEXP GPB_SetOffsetData_R(
+	SEXP handle,
+	SEXP fixed_effects
+);
+
 /*!
 * \brief Get additional likelihood parameters (e.g., shape parameter for a gamma likelihood)
 * \param handle Handle of REModel
